# Bigraph-viz

[![PyPI](https://img.shields.io/pypi/v/bigraph-viz.svg)](https://pypi.org/project/bigraph-viz/)
[![GitHub Pages](https://img.shields.io/badge/GitHub%20Pages-Tutorial-brightgreen)](https://vivarium-collective.github.io/bigraph-viz/notebooks/basics.html)

**Bigraph-viz** is an easy-to-use plotting tool for compositional bigraph schema, built on top of Graphviz. Visualize your bigraph schema with this Python library, designed for simplicity and flexibility.

<p align="center">
    <img src="https://github.com/vivarium-collective/bigraph-viz/blob/main/doc/_static/nested_composite.png?raw=true" width="340" alt="Bigraph-viz example">
</p>

## 🚀 Getting Started

### Prerequisites

- [Graphviz](https://pypi.org/project/graphviz/) - Bigraph-viz requires Graphviz to be installed.

### Installation

Bigraph-viz is available on [PyPI](https://pypi.org/project/bigraph-viz/) and can be installed with `pip`:

```console
$ pip install bigraph-viz
```

## 📚 Tutorial

To get started with Bigraph-viz, explore the [Bigraph Schema Basics](https://vivarium-collective.github.io/bigraph-viz/notebooks/basics.html) tutorial.

## 📖 Documentation

Coming soon!

## 📄 License

This project is licensed under the [MIT License](LICENSE).

